==> qupzilla_1.6.6.orig.tar.xz: qupzilla-1.6.6.orig/src/plugins/StatusBarIcons/translations/sk_SK.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="sk_SK" version="2.0">
<context>
    <name>SBI_ImagesIcon</name>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="36"/>
        <source>Modify images loading settings per-site and globally</source>
        <translation>Zmeniť nastavenie nahrávania obrázkov podľa stránky alebo globálne</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="60"/>
        <source>Current page settings</source>
        <translation>Nastavenia aktuálnej stránky</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="63"/>
        <source>Disable loading images (temporarily)</source>
        <translation>Zakázať načítanie obrázkov (dočasne)</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="66"/>
        <source>Enable loading images (temporarily)</source>
        <translation>Povoliť načítanie obrázkov (dočasne)</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="70"/>
        <source>Global settings</source>
        <translation>Globálne nastavenia</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="72"/>
        <source>Automatically load images</source>
        <translation>Automaticky načítavať obrázky</translation>
    </message>
</context>
<context>
    <name>SBI_JavaScriptIcon</name>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="34"/>
        <source>Modify JavaScript settings per-site and globally</source>
        <translation>Zmeniť nastavenie JavaScriptu podľa stránky alebo globálne</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="49"/>
        <source>Current page settings</source>
        <translation>Nastavenia aktuálnej stránky</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="52"/>
        <source>Disable JavaScript (temporarily)</source>
        <translation>Zakázať JavaScript (dočasne)</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="55"/>
        <source>Enable JavaScript (temporarily)</source>
        <translation>Povoliť JacaScript (dočasne)</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="59"/>
        <source>Global settings</source>
        <translation>Globálne nastavenia</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="60"/>
        <source>Manage JavaScript settings</source>
        <translation>Spravovať nastavení JavaScriptuia</translation>
    </message>
</context>
<context>
    <name>SBI_NetworkIcon</name>
    <message>
        <location filename="../sbi_networkicon.cpp" line="68"/>
        <source>Proxy configuration</source>
        <translation>Konfigurácia proxy</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="70"/>
        <source>Select proxy</source>
        <translation>Vybrať proxy</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="84"/>
        <source>Empty</source>
        <translation>Prázdne</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="88"/>
        <source>Manage proxies</source>
        <translation>Spravovať proxy</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="101"/>
        <source>Shows network status and manages proxy&lt;br/&gt;&lt;br/&gt;&lt;b&gt;Network:&lt;/b&gt;&lt;br/&gt;%1&lt;br/&gt;&lt;br/&gt;&lt;b&gt;Proxy:&lt;/b&gt;&lt;br/&gt;%2</source>
        <translation>Zobrazuje stav siete a spravuje proxy&lt;br/&gt;&lt;br/&gt;&lt;b&gt;Sieť:&lt;/b&gt;&lt;br/&gt;%1&lt;br/&gt;&lt;br/&gt;&lt;b&gt;Proxy:&lt;/b&gt;&lt;br/&gt;%2</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="104"/>
        <source>Connected</source>
        <translation>Pripojené</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="107"/>
        <source>Offline</source>
        <translation>Odpojené</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="112"/>
        <source>System proxy</source>
        <translation>Systémové proxy</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="116"/>
        <source>No proxy</source>
        <translation>Žiadne proxy</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="120"/>
        <source>PAC (Proxy Auto-Config)</source>
        <translation>PAC (Proxy Auto-Config)</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="124"/>
        <source>User defined</source>
        <translation>Určené používateľom</translation>
    </message>
</context>
<context>
    <name>SBI_NetworkIconDialog</name>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="14"/>
        <source>Proxy Manager</source>
        <translation>Správca proxy</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="28"/>
        <source>Select proxy: </source>
        <translation>Vyberte proxy:</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="38"/>
        <location filename="../sbi_networkicondialog.cpp" line="55"/>
        <source>Add proxy</source>
        <translation>Pridať proxy</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="45"/>
        <source>Remove proxy</source>
        <translation>Odstrániť proxy</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="69"/>
        <source>No proxies. You can add proxy by clicking on &lt;b&gt;Add&lt;/b&gt; button.</source>
        <translation>Žiadne proxy. Môžete ich pridať pomocou kliknutia na tlačidlo &lt;b&gt;Pridať&lt;/b&gt;.</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="104"/>
        <source>All changes must be saved with &lt;b&gt;Save&lt;/b&gt; button.</source>
        <translation>Všetky zmeny musia byť uložené pomocou tlačidla &lt;b&gt;Uložiť&lt;/b&gt;.</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.cpp" line="55"/>
        <source>Name of proxy:</source>
        <translation>Názov proxy:</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.cpp" line="68"/>
        <source>Remove current proxy</source>
        <translation>Odstrániť aktuálne proxy</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.cpp" line="68"/>
        <source>Are you sure to remove current proxy?</source>
        <translation>Ste si istý, že chcete odstrániť aktuálne proxy?</translation>
    </message>
</context>
<context>
    <name>SBI_ProxyWidget</name>
    <message>
        <location filename="../sbi_proxywidget.ui" line="14"/>
        <source>Form</source>
        <translation>Formulár</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="20"/>
        <source>Do not use proxy</source>
        <translation>Nepoužívať proxy</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="27"/>
        <source>Use different proxy for https connection</source>
        <translation>Použiť inú proxy pre https pripojenia</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="34"/>
        <source>&lt;b&gt;Exceptions&lt;/b&gt;</source>
        <translation>&lt;b&gt;Výnimky&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="43"/>
        <source>Don&apos;t use on:</source>
        <translation>Nepužívať na:</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="58"/>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="63"/>
        <source>SOCKS5</source>
        <translation>SOCKS5</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="74"/>
        <location filename="../sbi_proxywidget.ui" line="220"/>
        <source>Port:</source>
        <translation>Port:</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="111"/>
        <location filename="../sbi_proxywidget.ui" line="243"/>
        <source>Username:</source>
        <translation>Meno používateľa:</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="121"/>
        <location filename="../sbi_proxywidget.ui" line="253"/>
        <source>Password:</source>
        <translation>Heslo:</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="146"/>
        <source>Use script for automatic configuration:</source>
        <translation>Použiť skript pre automatickú konfiguráciu:</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="153"/>
        <source>System proxy configuration</source>
        <translation>Nastavenie systémového proxy</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="162"/>
        <source>Proxy Auto-Config (.pac) file</source>
        <translation>súbor Proxy Auto-Config (.pac)</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="187"/>
        <source>Manual configuration</source>
        <translation>Manuálne nastavenie</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="210"/>
        <source>Server:</source>
        <translation>Server:</translation>
    </message>
</context>
<context>
    <name>SBI_SettingsDialog</name>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="14"/>
        <source>StatusBar Icons</source>
        <translation>Ikony statusbaru</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="48"/>
        <source>&lt;h3&gt;StatusBar Icons&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;Ikony statusbaru&lt;/h3&gt;</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="70"/>
        <source>These icons will be displayed in statusbar:</source>
        <translation>Tieto ikony sa zobrazia v stavovom riadku:</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="97"/>
        <source>Images Icon</source>
        <translation>Ikona obrázkov</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="104"/>
        <source>JavaScript Icon</source>
        <translation>Ikona JavaScriptu</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="111"/>
        <source>Network Icon</source>
        <translation>Ikona siete</translation>
    </message>
</context>
</TS>

==> qupzilla_1.8.9~dfsg1.orig.tar.xz: qupzilla-1.8.9~dfsg1/src/plugins/StatusBarIcons/translations/sk_SK.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="sk_SK" version="2.0">
<context>
    <name>SBI_ImagesIcon</name>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="32"/>
        <source>Modify images loading settings per-site and globally</source>
        <translation>Zmeniť nastavenie nahrávania obrázkov podľa stránky alebo globálne</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="56"/>
        <source>Current Page Settings</source>
        <translation>Nastavenia aktuálnej stránky</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="59"/>
        <source>Disable loading images (temporarily)</source>
        <translation>Zakázať načítanie obrázkov (dočasne)</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="62"/>
        <source>Enable loading images (temporarily)</source>
        <translation>Povoliť načítanie obrázkov (dočasne)</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="66"/>
        <source>Global Settings</source>
        <translation>Globálne nastavenia</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="68"/>
        <source>Automatically load images</source>
        <translation>Automaticky načítavať obrázky</translation>
    </message>
</context>
<context>
    <name>SBI_JavaScriptIcon</name>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="33"/>
        <source>Modify JavaScript settings per-site and globally</source>
        <translation>Zmeniť nastavenie JavaScriptu podľa stránky alebo globálne</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="50"/>
        <source>Current Page Settings</source>
        <translation>Nastavenia aktuálnej stránky</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="53"/>
        <source>Disable JavaScript (temporarily)</source>
        <translation>Zakázať JavaScript (dočasne)</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="56"/>
        <source>Enable JavaScript (temporarily)</source>
        <translation>Povoliť JacaScript (dočasne)</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="65"/>
        <source>Global Settings</source>
        <translation>Globálne nastavenia</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="66"/>
        <source>Manage JavaScript settings</source>
        <translation>Spravovať nastavení JavaScriptuia</translation>
    </message>
</context>
<context>
    <name>SBI_NetworkIcon</name>
    <message>
        <location filename="../sbi_networkicon.cpp" line="66"/>
        <source>Proxy Configuration</source>
        <translation>Konfigurácia proxy</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="68"/>
        <source>Select proxy</source>
        <translation>Vybrať proxy</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="82"/>
        <source>Empty</source>
        <translation>Prázdne</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="86"/>
        <source>Manage proxies</source>
        <translation>Spravovať proxy</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="99"/>
        <source>Shows network status and manages proxy&lt;br/&gt;&lt;br/&gt;&lt;b&gt;Network:&lt;/b&gt;&lt;br/&gt;%1&lt;br/&gt;&lt;br/&gt;&lt;b&gt;Proxy:&lt;/b&gt;&lt;br/&gt;%2</source>
        <translation>Zobrazuje stav siete a spravuje proxy&lt;br/&gt;&lt;br/&gt;&lt;b&gt;Sieť:&lt;/b&gt;&lt;br/&gt;%1&lt;br/&gt;&lt;br/&gt;&lt;b&gt;Proxy:&lt;/b&gt;&lt;br/&gt;%2</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="102"/>
        <source>Connected</source>
        <translation>Pripojené</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="105"/>
        <source>Offline</source>
        <translation>Odpojené</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="110"/>
        <source>System proxy</source>
        <translation>Systémové proxy</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="114"/>
        <source>No proxy</source>
        <translation>Žiadne proxy</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="118"/>
        <source>PAC (Proxy Auto-Config)</source>
        <translation>PAC (Proxy Auto-Config)</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="122"/>
        <source>User defined</source>
        <translation>Určené používateľom</translation>
    </message>
</context>
<context>
    <name>SBI_NetworkIconDialog</name>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="14"/>
        <source>Proxy Manager</source>
        <translation>Správca proxy</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="28"/>
        <source>Select proxy: </source>
        <translation>Vyberte proxy:</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="38"/>
        <location filename="../sbi_networkicondialog.cpp" line="55"/>
        <source>Add proxy</source>
        <translation>Pridať proxy</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="45"/>
        <source>Remove proxy</source>
        <translation>Odstrániť proxy</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="69"/>
        <source>No proxies. You can add proxy by clicking on &lt;b&gt;Add&lt;/b&gt; button.</source>
        <translation>Žiadne proxy. Môžete ich pridať pomocou kliknutia na tlačidlo &lt;b&gt;Pridať&lt;/b&gt;.</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="104"/>
        <source>All changes must be saved with &lt;b&gt;Save&lt;/b&gt; button.</source>
        <translation>Všetky zmeny musia byť uložené pomocou tlačidla &lt;b&gt;Uložiť&lt;/b&gt;.</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.cpp" line="55"/>
        <source>Name of proxy:</source>
        <translation>Názov proxy:</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.cpp" line="68"/>
        <source>Remove current proxy</source>
        <translation>Odstrániť aktuálne proxy</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.cpp" line="68"/>
        <source>Are you sure to remove current proxy?</source>
        <translation>Ste si istý, že chcete odstrániť aktuálne proxy?</translation>
    </message>
</context>
<context>
    <name>SBI_ProxyWidget</name>
    <message>
        <location filename="../sbi_proxywidget.ui" line="14"/>
        <source>Form</source>
        <translation>Formulár</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="20"/>
        <source>Do not use proxy</source>
        <translation>Nepoužívať proxy</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="27"/>
        <source>Use different proxy for https connection</source>
        <translation>Použiť inú proxy pre https pripojenia</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="34"/>
        <source>&lt;b&gt;Exceptions&lt;/b&gt;</source>
        <translation>&lt;b&gt;Výnimky&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="43"/>
        <source>Don&apos;t use on:</source>
        <translation>Nepužívať na:</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="58"/>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="63"/>
        <source>SOCKS5</source>
        <translation>SOCKS5</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="74"/>
        <location filename="../sbi_proxywidget.ui" line="220"/>
        <source>Port:</source>
        <translation>Port:</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="111"/>
        <location filename="../sbi_proxywidget.ui" line="243"/>
        <source>Username:</source>
        <translation>Meno používateľa:</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="121"/>
        <location filename="../sbi_proxywidget.ui" line="253"/>
        <source>Password:</source>
        <translation>Heslo:</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="146"/>
        <source>Use script for automatic configuration:</source>
        <translation>Použiť skript pre automatickú konfiguráciu:</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="153"/>
        <source>System proxy configuration</source>
        <translation>Nastavenie systémového proxy</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="162"/>
        <source>Proxy Auto-Config (.pac) file</source>
        <translation>súbor Proxy Auto-Config (.pac)</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="187"/>
        <source>Manual configuration</source>
        <translation>Manuálne nastavenie</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="210"/>
        <source>Server:</source>
        <translation>Server:</translation>
    </message>
</context>
<context>
    <name>SBI_SettingsDialog</name>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="14"/>
        <source>StatusBar Icons</source>
        <translation>Ikony statusbaru</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="48"/>
        <source>&lt;h3&gt;StatusBar Icons&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;Ikony statusbaru&lt;/h3&gt;</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="70"/>
        <source>These icons will be displayed in statusbar:</source>
        <translation>Tieto ikony sa zobrazia v stavovom riadku:</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="97"/>
        <source>Images Icon</source>
        <translation>Ikona obrázkov</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="104"/>
        <source>JavaScript Icon</source>
        <translation>Ikona JavaScriptu</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="111"/>
        <source>Network Icon</source>
        <translation>Ikona siete</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="118"/>
        <source>Zoom widget</source>
        <translation>Zoom widget</translation>
    </message>
</context>
<context>
    <name>SBI_ZoomWidget</name>
    <message>
        <location filename="../sbi_zoomwidget.cpp" line="47"/>
        <source>Zoom: %1%</source>
        <translation>Zoom: %1%</translation>
    </message>
</context>
</TS>
